function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

var useActiveSession = function useActiveSession(postAction, timeout) {
  var _useState = React.useState(true),
      isActiveSession = _useState[0],
      setIsActiveSession = _useState[1];

  React.useEffect(function () {
    if (isActiveSession) {
      var now = new Date().getTime();
      localStorage.setItem('lastEvent', String(now));
      var timer = setInterval(function () {
        var lastEvent = Number(localStorage.getItem('lastEvent'));
        var now = new Date().getTime();

        if (now > lastEvent + timeout) {
          setIsActiveSession(false);
          localStorage.removeItem('lastEvent');
          postAction();
        }
      }, 1000);
      return function () {
        clearInterval(timer);
      };
    }
  }, [isActiveSession, postAction]);

  var updateLastEvent = function updateLastEvent() {
    var eventDate = new Date().getTime();
    localStorage.setItem('lastEvent', String(eventDate));
  };

  var eventTrigger = React.useCallback(updateLastEvent, []);
  return {
    isActiveSession: isActiveSession,
    eventTrigger: eventTrigger
  };
};

var ActiveSession = function ActiveSession(_ref) {
  var children = _ref.children,
      timeout = _ref.timeout,
      postAction = _ref.postAction,
      preAction = _ref.preAction,
      events = _ref.events;

  var _useActiveSession = useActiveSession(postAction, timeout),
      eventTrigger = _useActiveSession.eventTrigger,
      isActiveSession = _useActiveSession.isActiveSession;

  React__default.useEffect(function () {
    if (preAction) {
      preAction();
    }
  }, [preAction]);
  React__default.useEffect(function () {
    if (isActiveSession) {
      events.forEach(function (event) {
        document.addEventListener(event, eventTrigger, true);
      });
    } else {
      events.forEach(function (event) {
        document.removeEventListener(event, eventTrigger, true);
      });
    }
  }, [eventTrigger, isActiveSession]);
  return React__default.createElement(React__default.Fragment, null, children);
};

var DEFAULT_EVENTS = ['click', 'mousemove', 'keydown', 'scroll', 'drag'];

var ActiveSessionProvider = function ActiveSessionProvider(_ref) {
  var children = _ref.children,
      timeout = _ref.timeout,
      postAction = _ref.postAction,
      preAction = _ref.preAction,
      _ref$isEnabled = _ref.isEnabled,
      isEnabled = _ref$isEnabled === void 0 ? true : _ref$isEnabled,
      _ref$events = _ref.events,
      events = _ref$events === void 0 ? DEFAULT_EVENTS : _ref$events;
  return isEnabled ? React__default.createElement(ActiveSession, {
    postAction: postAction,
    timeout: timeout,
    preAction: preAction,
    events: events
  }, children) : React__default.createElement(React__default.Fragment, null, children);
};

exports.ActiveSessionProvider = ActiveSessionProvider;
//# sourceMappingURL=index.js.map
