import React, { useState, useEffect, useCallback } from 'react';

var useActiveSession = function useActiveSession(postAction, timeout) {
  var _useState = useState(true),
      isActiveSession = _useState[0],
      setIsActiveSession = _useState[1];

  useEffect(function () {
    if (isActiveSession) {
      var now = new Date().getTime();
      localStorage.setItem('lastEvent', String(now));
      var timer = setInterval(function () {
        var lastEvent = Number(localStorage.getItem('lastEvent'));
        var now = new Date().getTime();

        if (now > lastEvent + timeout) {
          setIsActiveSession(false);
          localStorage.removeItem('lastEvent');
          postAction();
        }
      }, 1000);
      return function () {
        clearInterval(timer);
      };
    }
  }, [isActiveSession, postAction]);

  var updateLastEvent = function updateLastEvent() {
    var eventDate = new Date().getTime();
    localStorage.setItem('lastEvent', String(eventDate));
  };

  var eventTrigger = useCallback(updateLastEvent, []);
  return {
    isActiveSession: isActiveSession,
    eventTrigger: eventTrigger
  };
};

var ActiveSession = function ActiveSession(_ref) {
  var children = _ref.children,
      timeout = _ref.timeout,
      postAction = _ref.postAction,
      preAction = _ref.preAction,
      events = _ref.events;

  var _useActiveSession = useActiveSession(postAction, timeout),
      eventTrigger = _useActiveSession.eventTrigger,
      isActiveSession = _useActiveSession.isActiveSession;

  React.useEffect(function () {
    if (preAction) {
      preAction();
    }
  }, [preAction]);
  React.useEffect(function () {
    if (isActiveSession) {
      events.forEach(function (event) {
        document.addEventListener(event, eventTrigger, true);
      });
    } else {
      events.forEach(function (event) {
        document.removeEventListener(event, eventTrigger, true);
      });
    }
  }, [eventTrigger, isActiveSession]);
  return React.createElement(React.Fragment, null, children);
};

var DEFAULT_EVENTS = ['click', 'mousemove', 'keydown', 'scroll', 'drag'];

var ActiveSessionProvider = function ActiveSessionProvider(_ref) {
  var children = _ref.children,
      timeout = _ref.timeout,
      postAction = _ref.postAction,
      preAction = _ref.preAction,
      _ref$isEnabled = _ref.isEnabled,
      isEnabled = _ref$isEnabled === void 0 ? true : _ref$isEnabled,
      _ref$events = _ref.events,
      events = _ref$events === void 0 ? DEFAULT_EVENTS : _ref$events;
  return isEnabled ? React.createElement(ActiveSession, {
    postAction: postAction,
    timeout: timeout,
    preAction: preAction,
    events: events
  }, children) : React.createElement(React.Fragment, null, children);
};

export { ActiveSessionProvider };
//# sourceMappingURL=index.modern.js.map
